==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/test/item/LifeAggregatorTest.java <==
package vazkii.botania.test.item;

import net.minecraft.class_1268;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_243;
import net.minecraft.class_2680;
import net.minecraft.class_3965;
import net.minecraft.class_4516;
import net.minecraft.class_6302;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.common.item.LifeAggregatorItem;
import vazkii.botania.test.TestingUtil;

public class LifeAggregatorTest {
	@class_6302(method_35936 = TestingUtil.EMPTY_STRUCTURE)
	public void testSpawnerMover(class_4516 helper) {
		var spawnerPos = class_2338.field_10980;
		var player = helper.method_36021();
		var stack = new class_1799(BotaniaItems.spawnerMover);

		helper.method_35984(spawnerPos, class_2246.field_10260);
		player.method_6122(class_1268.field_5808, stack);

		stack.method_7981(new class_1838(player, class_1268.field_5808,
				new class_3965(class_243.field_1353, class_2350.field_11033, helper.method_36052(spawnerPos), false)));
		TestingUtil.assertThat(LifeAggregatorItem.hasData(stack),
				() -> "Spawner mover should recognize saved data. Full NBT: " + stack.method_7969());
		helper.method_36017(spawnerPos, class_2680::method_26215, () -> "Spawner should be gone");

		stack.method_7981(new class_1838(player, class_1268.field_5808,
				new class_3965(class_243.field_1353, class_2350.field_11036, helper.method_36052(spawnerPos.method_10074()), false)));
		helper.method_35972(class_2246.field_10260, spawnerPos);
		TestingUtil.assertThat(stack.method_7960(), () -> "Spawner mover should be broken after placing");

		helper.method_35984(spawnerPos, class_2246.field_10124); // Don't spawn mobs that interfere with other continuing tests
		helper.method_36036();
	}
}

==> Botania-1.20.1-451-FABRIC-20251025.172342-22-sources.jar: vazkii/botania/test/item/LifeAggregatorTest.java <==
package vazkii.botania.test.item;

import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1299;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_243;
import net.minecraft.class_2636;
import net.minecraft.class_2680;
import net.minecraft.class_3965;
import net.minecraft.class_4516;
import net.minecraft.class_5819;
import net.minecraft.class_6302;
import vazkii.botania.common.item.BotaniaItems;
import vazkii.botania.common.item.LifeAggregatorItem;
import vazkii.botania.test.TestingUtil;

public class LifeAggregatorTest {
	@class_6302(method_35936 = TestingUtil.EMPTY_STRUCTURE)
	public void testSpawnerMover(class_4516 helper) {
		var spawnerPos = class_2338.field_10980;
		var player = helper.method_36021();
		var stack = new class_1799(BotaniaItems.spawnerMover);

		helper.method_35984(spawnerPos, class_2246.field_10260);
		class_2636 be = (class_2636) helper.method_36014(spawnerPos);
		be.method_46408(class_1299.field_6093, class_5819.method_43047());

		player.method_6122(class_1268.field_5808, stack);

		class_1269 result = stack.method_7981(new class_1838(player, class_1268.field_5808,
				new class_3965(class_243.field_1353, class_2350.field_11033, helper.method_36052(spawnerPos), false)));
		TestingUtil.assertThat(result.method_23665(), () -> "Should have succeeded");
		TestingUtil.assertThat(LifeAggregatorItem.hasData(stack),
				() -> "Spawner mover should recognize saved data. Full NBT: " + stack.method_7969());
		helper.method_36017(spawnerPos, class_2680::method_26215, () -> "Spawner should be gone");

		result = stack.method_7981(new class_1838(player, class_1268.field_5808,
				new class_3965(class_243.field_1353, class_2350.field_11036, helper.method_36052(spawnerPos.method_10074()), false)));
		TestingUtil.assertThat(result.method_23665(), () -> "Should have succeeded");
		helper.method_35972(class_2246.field_10260, spawnerPos);
		TestingUtil.assertThat(stack.method_7960(), () -> "Spawner mover should be broken after placing");

		helper.method_35984(spawnerPos, class_2246.field_10124); // Don't spawn mobs that interfere with other continuing tests
		helper.method_36036();
	}
}
